@@ -19,80 +19,75 @@
 
 using System;
 using System.Collections.Generic;
-using gbrainy.Core.Libraries;
 
-using Mono.Unix;
+using gbrainy.Core.Libraries;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Core.Main.Verbal
 {
 	public abstract class Analogies : Game
 	{
-		protected Analogy current;
+		public Analogy Current { get; set; }
 
 		public override string Question {
 			get {
-				if (current == null)
+				if (Current == null)
 					return string.Empty;
 
-				return current.question;
+				return Current.question;
 			}
 		}
 
 		public override string Tip {
 			get {
-				if (current == null)
+				if (Current == null)
 					return null;
 				else
-					return current.tip;
-			}
-		}
-
-		public override string Answer {
-			get {
-				string str;
-				if (current == null || current.MultipleAnswers == false)
-					return base.Answer;
-
-				str = String.Format (Catalog.GetString ("Possible correct answers are: {0}."), AnswerValue);
-
-				if (String.IsNullOrEmpty (Rationale))
-					return str;
-				
-				// Translators: answer + rationale of the answer
-				return  String.Format (Catalog.GetString ("{0} {1}"), str, Rationale);
+					return Current.tip;
 			}
 		}
 
 		public override string Rationale {
 			get {
-				if (current == null)
+				if (Current == null)
 					return string.Empty;
-				
-				return current.rationale;
+
+				if (Current.MultipleAnswers == false || String.IsNullOrEmpty (Current.rationale))
+					return Current.rationale;
+
+				string str;	
+				str = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Possible correct answers are: {0}."), 
+					Answer.CorrectShow);
+
+				// For multiple answer build a rationale
+				// Translators: answer + rationale of the answer
+				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0} {1}"), str, 
+					Current.rationale);
 			}
 		}
 
-		public override string AnswerValue {
-			get { 
-				if (current == null || current.MultipleAnswers == false)
-					return right_answer;
+		protected void SetAnswerCorrectShow ()
+		{
+			if (Current == null || 
+			    Current.MultipleAnswers == false ||
+			    String.IsNullOrEmpty (Answer.Correct))
+				return;
 
-				string [] items;
-				string str = string.Empty;
+			string [] items;
+			string str = string.Empty;
 
-				items = right_answer.Split (AnalogiesFactory.Separator);
+			items = Answer.Correct.Split (AnalogiesFactory.Separator);
 
-				for (int i = 0 ; i < items.Length; i++)
-				{
-					str += items [i].Trim ();
-					if (i + 1 < items.Length) {
-						// Translators: this the separator used when concatenating multiple possible answers for verbal analogies
-						// For example: "Possible correct answers are: sleep, rest."
-						str += Catalog.GetString (", ");
-					}
+			for (int i = 0 ; i < items.Length; i++)
+			{
+				str += items [i].Trim ();
+				if (i + 1 < items.Length) {
+					// Translators: this the separator used when concatenating multiple possible answers for verbal analogies
+					// For example: "Possible correct answers are: sleep, rest."
+					str += ServiceLocator.Instance.GetService <ITranslations> ().GetString (", ");
 				}
-				return str;
 			}
+			Answer.CorrectShow = str;
 		}
 
 		public override GameTypes Type {
@@ -131,7 +126,7 @@ namespace gbrainy.Core.Main.Verbal
 					if (GetText.StringExists (analogy.answers [indices[i]]) == false)
 						localized = false;
 
-					answers [i] = Catalog.GetString (analogy.answers [indices[i]]);
+					answers [i] = ServiceLocator.Instance.GetService <ITranslations> ().GetString (analogy.answers [indices[i]]);
 					if (indices[i] == analogy.right)
 						new_right = i;
 				}
@@ -145,13 +140,13 @@ namespace gbrainy.Core.Main.Verbal
 				localized = false;
 
 			if (localized == true) {
-				analogy.question = Catalog.GetString (analogy.question);
+				analogy.question = ServiceLocator.Instance.GetService <ITranslations> ().GetString (analogy.question);
 
 				if (String.IsNullOrEmpty (analogy.tip) == false)
-					analogy.tip = Catalog.GetString (analogy.tip);
+					analogy.tip = ServiceLocator.Instance.GetService <ITranslations> ().GetString (analogy.tip);
 
 				if (String.IsNullOrEmpty (analogy.rationale) == false)
-					analogy.rationale = Catalog.GetString (analogy.rationale);
+					analogy.rationale = ServiceLocator.Instance.GetService <ITranslations> ().GetString (analogy.rationale);
 			} else {
 
 				// Get analogy again
@@ -170,7 +165,6 @@ namespace gbrainy.Core.Main.Verbal
 					analogy.answers = answers;
 				}
 			}
-
 			return analogy;
 		}
 	}
