@@ -19,10 +19,10 @@
 
 using System;
 using Cairo;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Logic
 {
@@ -32,33 +32,34 @@ namespace gbrainy.Games.Logic
 		private const double sub_figure = 0.15;
 
 		public override string Name {
-			get {return Catalog.GetString ("Missing piece");}
+			get {return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Missing piece");}
 		}
 
 		public override string Question {
 			get {return String.Format (
-				Catalog.GetString ("Which square completes the figure below? Answer {0}, {1} or {2}."),
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2));}
+				ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Which square completes the figure below? Answer {0}, {1} or {2}."),
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2));}
 		}
 
 		public override string Tip {
-			get { return Catalog.GetString ("The logic works at row level.");}
+			get { return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The logic works at row level.");}
 		}
 
 		public override string Rationale {
 			get {
-				return Catalog.GetString ("In every row the third square is made by flipping the first square and superimposing it on the second square, followed by removing the matching lines.");
+				return ServiceLocator.Instance.GetService <ITranslations> ().GetString ("In every row the third square is made by flipping the first square and superimposing it on the second square, followed by removing the matching lines.");
 			}
 		}
 
 		protected override void Initialize ()
 		{
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption| GameAnswerCheckAttributes.IgnoreSpaces;
 			random_indices = new ArrayListIndicesRandom (3);
 			random_indices.Initialize ();
 
 			for (int i = 0; i < random_indices.Count; i++) {
 				if (random_indices [i] == 0) {
-					right_answer = GetPossibleAnswer (i);
+					Answer.SetMultiOptionAnswer (i, Answer.GetFigureName (i));
 					break;
 				}
 			}
@@ -73,7 +74,7 @@ namespace gbrainy.Games.Logic
 						
 				drawable_area.SelectedArea = new Rectangle (0, 0, sub_figure, sub_figure);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 				container.AddChild (drawable_area);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
@@ -82,12 +83,12 @@ namespace gbrainy.Games.Logic
 
 					DrawAnswerFigures (e.Context, 0, 0, random_indices [n]);
 					e.Context.MoveTo (0, 0.2);
-					e.Context.ShowPangoText (GetPossibleFigureAnswer (n));
+					e.Context.ShowPangoText (Answer.GetFigureName (n));
 				};
 			}
 		}
 
-		private void DrawFigureSequence (CairoContextEx gr, double x, double y, int sequence, bool last_block)
+		static private void DrawFigureSequence (CairoContextEx gr, double x, double y, int sequence, bool last_block)
 		{
 			gr.Rectangle (x, y, sub_figure, sub_figure);
 			gr.Rectangle (x + sub_figure, y, sub_figure, sub_figure);
@@ -135,7 +136,7 @@ namespace gbrainy.Games.Logic
 			gr.Stroke ();
 		}
 
-		private void DrawAnswerFigures (CairoContextEx gr, double x, double y, int figure)
+		static private void DrawAnswerFigures (CairoContextEx gr, double x, double y, int figure)
 		{
 			gr.Rectangle (x, y, sub_figure, sub_figure);
 
@@ -169,7 +170,7 @@ namespace gbrainy.Games.Logic
 			DrawFigureSequence (gr, x, DrawAreaY + sub_figure * 2 , 2, false);
 
 			gr.MoveTo (0.1, 0.62);
-			gr.ShowPangoText (Catalog.GetString ("Possible answers are:"));
+			gr.ShowPangoText (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("Choose one of the following:"));
 		}
 	}
 }
